package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`%0`!`````",```````!``````````#`!`0``
M`````@```$``.``'`$``%@`5``8````$````0`````````!``````````$``
M````````B`$```````"(`0````````@``````````P````0```#(`0``````
M`,@!````````R`$````````>`````````!X``````````0`````````!````
M!0```````````````````````````````````$B;````````2)L`````````
M``$```````$````&````(/L````````@^P$``````"#[`0``````6`4`````
M``#`%0```````````0```````@````8```!(^P```````$C[`0``````2/L!
M``````#``0```````,`!````````"`````````!1Y71D!@``````````````
M```````````````````````````````````````````0`````````%+E=&0$
M````(/L````````@^P$``````"#[`0``````X`0```````#@!`````````$`
M````````+VQI8B]L9"UM=7-L+7!O=V5R<&,V-&QE+G-O+C$````1````3@``
M``(````'````FH4`"`E`!$E(CA1!BH0`Z`````!.````4@```%8```!7````
M7````%T```!>`````````&```````````````&$```!B````8P``````````
M````:G^:?.K3[P[.WD<M;\7?'R[%F[:XC?$.U&34?"'_Y`[9<5@<^J%L8,+E
M/RRR`8MOXD?&`;OCDGQ5PSS29Z_,9H@'<--#1=7L,V+;[7^IG)OAIP(*H^#[
M20```````````````````````````````````````````P`'`(`8````````
M`````````````````P`,`"#[`0`````````````````,````$F``````````
M``````````````#3`0``$F`````````````````````````4````$0``````
M``````````````````#Y`0``$0````````````````````````!U`0``$F``
M```````````````````````;````$F````````````````````````"R`0``
M$F`````````````````````````C````$F`````````````````````````&
M`@``$F````````````````````````"^`0``$F``````````````````````
M```J````(`````````````````````````!)`P``(0``````````````````
M``````!"````$F````````````````````````!(````$@``````````````
M``````````!/````$@`````````````````````````6`P``$F``````````
M```````````````'`P``$F````````````````````````"+`@``$F``````
M``````````````````!6````$@`````````````````````````L`@``$F``
M``````````````````````!=````$F````````````````````````#``@``
M$F````````````````````````!D````$F````````````````````````!L
M````(`````````````````````````"`````$@``````````````````````
M``"I`@``$F````````````````````````"(````$F``````````````````
M``````".````$F````````````````````````"7````(```````````````
M`````````````P``$F````````````````````````"S````$F``````````
M``````````````"X````$F`````````````````````````7`@``$0``````
M``````````````````#'`@``$F````````````````````````!9`@``$F``
M``````````````````````"_````$F````````````````````````!+`@``
M$F````````````````````````"%`P``$F````````````````````````#2
M`@``$0````````````````````````!(`P``$0``````````````````````
M``!]`@``$F`````````````````````````U`P``$F``````````````````
M``````!*`P``$0````````````````````````#&````$F``````````````
M```````````M`P``$F````````````````````````"#`0``$F``````````
M``````````````#/````(@````````````````````````#>````(```````
M``````````````````#T````$F````````````````````````#X`@``$F``
M``````````````````````!I`@``$F````````````````````````#Y````
M$F````````````````````````#_````(`````````````````````````"T
M`@``$F`````````````````````````9`0``$F``````````````````````
M``"C`0``$F`````````````````````````>`0``$F``````````````````
M``````"9`@``$F````````````````````````"2`0``$F``````````````
M```````````D`0``$@`````````````````````````U`0``$F``````````
M```````````````G`@``$F````````````````````````")````$F``````
M```````````````````X`@``$F````````````````````````!R`@``$F``
M```````````````````````F`P``$F`````````````````````````[`0``
M$@`````````````````````````>`P``$F````````````````````````!/
M`0``$@`````````````````````````B`@``$F``````````````````````
M``#A`0``$F````````````````````````!6`0``$@``````````````````
M``````!=`0``$@````````````````````````!'`P``(0``````````````
M``````````!N`0``$@````````````````````````!"`P``$F`(`&`@````
M````H`(```````#S`0``$F`)`/Q;````````$`````````#'`P``$F`(`%!+
M````````W`D````````]!```$F`(``Q9````````F`````````"D`P``$F`(
M`"!$````````&`````````#6`P``$F`'`(`8````````$`````````#J`P``
M$F`(`"Q5````````X`,````````P!```$F`(`#A$````````$`(```````!9
M`P``$``3`'@``@````````````````"U`P``$F`(`(Q*````````Q```````
M``#4`P``$F`(`&!"````````9`````````#<`P``$F`(`*A)````````C```
M```````*!```$@`(`$A&````````.`````````!E`P``$``3`.`0`@``````
M``````````!J`P``$F`(`"PC````````3``````````7!```$F`(`(!&````
M````9`$`````````!```$0`2`'```@``````"`````````!2`P``$``2`'@`
M`@````````````````!>`P``$@`(```C``````````````````!S`P``$F`(
M`#1*````````6`````````".`P``$F`(`#Q#````````Y``````````C!```
M$F`(`.1'````````Q`$`````````;&EB<&5R;"YS;P!O<&5N9&ER`'-T9&5R
M<@!R96%L;&]C`&%C8V5S<P!?7V1E<F5G:7-T97)?9G)A;65?:6YF;P!L<V5E
M:P!G971P:60`<W1R8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!?2G9?4F5G
M:7-T97)#;&%S<V5S`'-T<FYC;7``;'-T870`8VQO<V5D:7(`7TE435]D97)E
M9VES=&5R5$U#;&]N951A8FQE`&]P96X`<W1R<W1R`'-T<F-H<@!R96%D;&EN
M:P!?7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V9R86UE7VEN9F\`97AI=`!C
M;&]S90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`')E860`<FUD:7(`7U]E
M<G)N;U]L;V-A=&EO;@!M:V1I<@!P=&AR96%D7V=E='-P96-I9FEC`&UE;6-P
M>0!S=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?=&5R
M;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R
M=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?
M<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E
M<FQ?;F5W6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S
M970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F
M971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L
M7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F
M97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F,N;75S
M;"UP<&,V-&QE+G-O+C$`9G!R:6YT9@!S=')D=7``<'1H<F5A9%]A=&9O<FL`
M<F5A9&1I<@!S<')I;G1F`'-T<G1O:P!S=')N8W!Y`%]?;&EB8U]S=&%R=%]M
M86EN`%]?7V5N=FER;VX`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`7W-T87)T
M7V,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-U<G)E;G1?97AE
M8U]P<F]C`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E='5P7VQI8G!A=&@`<&%R
M7VUK=&UP9&ER`'AS7VEN:70`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?
M4$%27T)/3U0`;7E?<&%R7W!L`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P
M87)?:6YI=%]E;G8`<&%R7V9I;F1P<F]G`'!A<E]C;&5A;G5P`"]U<W(O;&EB
M+W!E<FPU+V-O<F5?<&5R;"]#3U)%``````(``````!8````````````"````
M```0``(``````!8`````````"E\````````8``(``````!8`````````55P`
M```````H``(``````!8`````````-ET````````P``(``````!8`````````
M+UT````````X``(``````!8`````````_EX```````!```(``````!8`````
M````3%T```````!(``(``````!8`````````!E\```````!8``(``````!8`
M````````\%X```````!@``(``````!8`````````]5X```````!P``(`````
M`!8`````````#U\````````(_P$``````"8````?```````````````0_P$`
M`````"8````W```````````````8_P$``````"8````Q```````````````@
M_P$``````"8````-```````````````H_P$``````"8````R````````````
M```P_P$``````"8````:```````````````X_P$``````"8````M````````
M``````!`_P$``````"8````C``````````````!(_P$``````"8````\````
M``````````!0_P$``````"8````%``````````````!8_P$``````"8```!"
M``````````````!@_P$``````"8````]``````````````!H_P$``````"8`
M```&``````````````!P_P$``````"8````I```````````````8_0$`````
M`!4````#```````````````@_0$``````!4````$```````````````H_0$`
M`````!4````'```````````````P_0$``````!4````(```````````````X
M_0$``````!4````)``````````````!`_0$``````!4````*````````````
M``!(_0$``````!4````+``````````````!0_0$``````!4````,````````
M``````!8_0$``````!4````-``````````````!@_0$``````!4````/````
M``````````!H_0$``````!4````0``````````````!P_0$``````!4````1
M``````````````!X_0$``````!4````2``````````````"`_0$``````!4`
M```3``````````````"(_0$``````!4````4``````````````"0_0$`````
M`!4````5``````````````"8_0$``````!4````6``````````````"@_0$`
M`````!4````7``````````````"H_0$``````!4````8``````````````"P
M_0$``````!4````9``````````````"X_0$``````!4````;````````````
M``#`_0$``````!4````<``````````````#(_0$``````!4````=````````
M``````#0_0$``````!4````>``````````````#8_0$``````!4````@````
M``````````#@_0$``````!4````A``````````````#H_0$``````!4````B
M``````````````#P_0$``````!4````D``````````````#X_0$``````!4`
M```E````````````````_@$``````!4````F```````````````(_@$`````
M`!4````G```````````````0_@$``````!4````H```````````````8_@$`
M`````!4````K```````````````@_@$``````!4````L```````````````H
M_@$``````!4````N```````````````P_@$``````!4````O````````````
M```X_@$``````!4````P``````````````!`_@$``````!4````Q````````
M``````!(_@$``````!4````R``````````````!0_@$``````!4````S````
M``````````!8_@$``````!4````T``````````````!@_@$``````!4````U
M``````````````!H_@$``````!4````V``````````````!P_@$``````!4`
M```X``````````````!X_@$``````!4````Y``````````````"`_@$`````
M`!4````Z``````````````"(_@$``````!4````[``````````````"0_@$`
M`````!4````^``````````````"8_@$``````!4````_``````````````"@
M_@$``````!4```!```````````````"H_@$``````!4```!!````````````
M``"P_@$``````!4```!#``````````````"X_@$``````!4```!$````````
M``````#`_@$``````!4```!%``````````````#(_@$``````!4```!&````
M``````````#0_@$``````!4```!'``````````````#8_@$``````!4```!(
M``````````````#@_@$``````!4```!)``````````````#H_@$``````!4`
M``!*``````````````#P_@$``````!4```!+``````````````#X_@$`````
M`!4```!-```````````````"`$P\@&9".*8""'P0``'XX?\A^.4,`$@```!@
M+4$`2````&`@`"$X$``!Z*8#"'P@`(!.````````````````&`!!^/__@CU`
M?XSII@.)?2`$@$X````````````````8`$'X__^"/?!_C.FF`XE](`2`3@``
M`````````````!@`0?C__X(]2'^,Z:8#B7T@!(!.````````````````&`!!
M^/__@CT(?XSII@.)?2`$@$X````````````````8`$'X__^"/1!_C.FF`XE]
M(`2`3@```````````````!@`0?C__X(]>'Z,Z:8#B7T@!(!.````````````
M````&`!!^/__@CV8?XSII@.)?2`$@$X````````````````8`$'X__^"/1A_
MC.FF`XE](`2`3@```````````````!@`0?C__X(]8'^,Z:8#B7T@!(!.````
M````````````&`!!^/__@CWX?XSII@.)?2`$@$X````````````````8`$'X
M__^"/3A^C.FF`XE](`2`3@```````````````!@`0?C__X(]H'^,Z:8#B7T@
M!(!.````````````````&`!!^/__@CTP?XSII@.)?2`$@$X`````````````
M```8`$'X__^"/=A^C.FF`XE](`2`3@```````````````!@`0?C__X(]P'^,
MZ:8#B7T@!(!.````````````````&`!!^/__@CU8?XSII@.)?2`$@$X`````
M```````````8`$'X__^"/7A_C.FF`XE](`2`3@```````````````!@`0?C_
M_X(]*'^,Z:8#B7T@!(!.````````````````&`!!^/__@CW@?XSII@.)?2`$
M@$X````````````````8`$'X__^"/;!^C.FF`XE](`2`3@``````````````
M`!@`0?C__X(]L'^,Z:8#B7T@!(!.````````````````&`!!^/__@CU`?HSI
MI@.)?2`$@$X````````````````8`$'X__^"/?!^C.FF`XE](`2`3@``````
M`````````!@`0?C__X(]T'Z,Z:8#B7T@!(!.````````````````&`!!^/__
M@CUH?HSII@.)?2`$@$X````````````````8`$'X__^"/9!_C.FF`XE](`2`
M3@```````````````!@`0?C__X(]^'Z,Z:8#B7T@!(!.````````````````
M&`!!^/__@CVH?XSII@.)?2`$@$X````````````````8`$'X__^"/8!_C.FF
M`XE](`2`3@```````````````!@`0?C__X(]('^,Z:8#B7T@!(!.````````
M````````&`!!^/__@CVX?XSII@.)?2`$@$X````````````````8`$'X__^"
M/0!_C.FF`XE](`2`3@```````````````!@`0?C__X(]R'^,Z:8#B7T@!(!.
M````````````````&`!!^/__@CU8?HSII@.)?2`$@$X````````````````8
M`$'X__^"/1A^C.FF`XE](`2`3@```````````````!@`0?C__X(]Z'Z,Z:8#
MB7T@!(!.````````````````&`!!^/__@CV(?HSII@.)?2`$@$X`````````
M```````8`$'X__^"/7!_C.FF`XE](`2`3@```````````````!@`0?C__X(]
MV'^,Z:8#B7T@!(!.````````````````&`!!^/__@CUH?XSII@.)?2`$@$X`
M```````````````8`$'X__^"/7!^C.FF`XE](`2`3@```````````````!@`
M0?C__X(]P'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CV(?XSII@.)
M?2`$@$X````````````````8`$'X__^"/:A^C.FF`XE](`2`3@``````````
M`````!@`0?C__X(]F'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CTP
M?HSII@.)?2`$@$X````````````````8`$'X__^"/9!^C.FF`XE](`2`3@``
M`````````````!@`0?C__X(]R'Z,Z:8#B7T@!(!.````````````````&`!!
M^/__@CTH?HSII@.)?2`$@$X````````````````8`$'X__^"/3A_C.FF`XE]
M(`2`3@```````````````!@`0?C__X(]N'Z,Z:8#B7T@!(!.````````````
M````&`!!^/__@CW@?HSII@.)?2`$@$X````````````````8`$'X__^"/5!_
MC.FF`XE](`2`3@```````````````!@`0?C__X(]Z'^,Z:8#B7T@!(!.````
M````````````&`!!^/__@CU@?HSII@.)?2`$@$X````````````````8`$'X
M__^"/:!^C.FF`XE](`2`3@```````````````!@`0?C__X(]('Z,Z:8#B7T@
M!(!.````````````````&`!!^/__@CU(?HSII@.)?2`$@$X`````````````
M```8`$'X__^"/8!^C.FF`XE](`2`3@```````````````!@`0?C__X(]4'Z,
MZ:8#B7T@!(!.````````````````&`!!^/__@CW0?XSII@.)?2`$@$X`````
M```````````"`$P\H%Y".*8""'SP_\'[^/_A^Q```?AQ_R'X<`"!^&@`H?AP
M`($X:`"A.'P`89!\`&$X3?[_2Q@`0>@```!@6("BZ````&!@@&+H>"ND?%'_
M_TL8`$'H````8&B`(ND```!@0(#BZP``R8L``)XO0`">0*WZ_TL8`$'H````
M8```HR_8D6+X$`">0`$`8#A1_O]+&`!!Z$G[_TL8`$'H``!_@'WY_TL8`$'H
ML0K#FP``?X!M^?]+&`!!Z(H&(XD"`"EAB@8CF0``?X!5^?]+&`!!Z(H&(XD!
M`"EAB@8CF7P`88#__R`YP``I>04`8SBT!V-\0$BC?QP`G4````!@<(""Z/[_
M8CR;W6,XM?[_2Q@`0>@D'V-XZ?O_2Q@`0>A^`*'H<`#AZ````&`!```YR)%B
M^````&!X&V9\```GZ0``A2\``"/Y_O\B/>K?*3D(`"/Y````8'"!(ND0`"/Y
M_O\B/>W?*3D8`"/Y!``@.<"1(I'__R4Y(``I>0$`*3D(`)U!`0`@.0$`*2S_
M_RDYX`""0`0`)3D``$`Y````8-B18NBT!RE]`P"E."0?*7G^_X(\%$HF?0``
MX#BT!Z5\Q,.$./C_2?FY^_]+&`!!Z'D;?WP8`()`````8-B18NB!]_]+&`!!
MZ'@;?WP```!@V)%BZ````&"X@<([1??_2Q@`0>C^_V(\Z=UC.+$:`$@``*,O
M.`">0````&#0D2+I``"I+Q0`GD#^_V(\GMUC.(T:`$@8$'[X````8-"18N@`
M`*,O"`">06TV`$@```!@V)%BZ,WZ_TL8`$'H!?S_2Q@`0>B0`"$X>/OC?^0W
M`$@)`(?H!`!(.;0'2GT!``@Y)!]*>;0'"'T44D9]^/^*^/C^_TL`````````
M`8`"```"`$P\`%Q"."@`C(`48H1\>`LC?.0&(7@````XX?\!^*8#"'P1``!(
M2-@!``(`3#S46T(XI@((?`@`HSC^_^(\_-SG./[_PCR`F<8X````.1```?CA
M_R'X`@"#Z/[_8CQ@H6,X_?C_2Q@`0>@``````````8````````!@````8`(`
M3#R`6T(X````8````&!_@2(Y>(%B.%!((WT.`*DK(`"=3````&`(@"+I``"I
M+R``GDVF`@A\>$LL?:8#*7T0``'XX?\A^!@`0?@A!(!.&`!!Z"``(3@0``'H
MI@,(?"``@$X```!@````8```0F`"`$P\$%M".````&````!@>(&".'B!8CA0
M((-\=!Z$?'0.A'R5`81\(`""30```&`0@"+I``"I+R``GDVF`@A\>$LL?:8#
M*7T0``'XX?\A^!@`0?@A!(!.&`!!Z"``(3@0``'HI@,(?"``@$X``$)@`@!,
M/*!:0C@```!@>($BB0``B2\@`)Y,I@((?````&`8@"+IZ/^A^_#_P?OX_^'[
M``"I+Q```?C!_R'X%`">00```&``@6+H&?3_2Q@`0>C__R(]___"/SA\*3DP
M?-X[4$C>?P```&"`@2+I__]"/70>WG\P?$HY___>.P```&!`\*E_>%-=?8"!
MXCLT`)Q``0`I.20?*GD``#_Y*E`]?1@`0?BF`RE]>$LL?2$$@$X8`$'H```_
MZ4!(OG_4_YU!:?[_2P```&`@@"+I``"I+Q0`GD'^_V(\1!QC.*7W_TL8`$'H
M0``A.`$`(#D```!@$``!Z.C_H>OP_\'K^/_AZWB!(IFF`PA\(`"`3@``0F`"
M`$P\D%E".*8""'P```!@*(`BZ0``J2\0``'XX?\A^!P`GD$```!@_O]B/(B!
M@CA$'&,X7?/_2Q@`0>C__R(]0'PI.7A+(WT``"/I``"I+R``GD`@`"$X$``!
MZ*8#"'PH_O]+````8````&```$)@````8#"`(ND``*DOV/^>0:8#*7T8`$'X
M>$LL?2$$@$X8`$'HP/__2P(`3#SX6$(XI@((?`@`0#FF`TE],`##."4T`$@!
M_2'X\(\MZ:@"(?D``"`Y*``!.0@`1CD0``@Y+%0@?0D`1NGP_RCY(,))>2(`
M1WDN!"E5($9*>7A3*7THP.IX>%,I?1Y"YU1X.RE]^/\H^<3_`$)``"`Y(``!
M.:8#*7UP`"CI2`#HZ!@`2.EX.BE]>%(I?0D`2.EX4BE]I`\J><(/*7EX2TE]
M(``I>8``*/G0_P!"```#Z"``8^D0`*/H&`"#Z`@`P^@P`.'KPBX)>*0N!WAX
M2^=\*``AZ8+PWG@@`.=X@EK_/YEY_SMD\!QX@EHI/10B_W^9>2DY%%HI?11*
MYWQX(JE\.#`I?7@B*7T42N=\9/#)>'CS*7T@`.IX(``^>2@H27EX\JA\@O!=
M>3@`"'UX*@A]%/H(?<(N7WEX^RE]>%#??Q1*"'V"\`EX>$N<?R``&WD@`)Q[
M*/!*>3C@YWQXZUU]>#OG?S@`X>O"+FE[..@*?8):_S^9>?\[%"K_?Q3ZYW\H
M*&=[>$OG?'C8B7]X4RI]0``AZ10Z_W\@`/I[PBY(>WC0IW^"6BD]F7DI.13R
M*7V"\'Y[%$HJ?2@H2GMX0TI]*/!H>WCS'GT44BE]./#H?R``.7EX0^A\2`#A
MZ"CP7WO"+BI[@EKG/)EYYS@4XN=\@O!<>WCC_'\4.NA\*"@H>SC@/WUX4PA]
M>,C*?WC[7WU0`$'I%$+G?"``^WC"+FE[>-B(?X):2CV9>4HY%.I*?8+P/7L4
M4E]]*"A_>WA+_W\H\"E[>.L]?13Z2GTXZ.E\(`!:>7A+"7U8``'IPBY'>WC0
MOW^"6@@]F7D(.13R"'V"\'Y[%$()?2@H27MX.RE]*/!G>WCS_GP42@A]./!'
M?2``&7EX.^=_8`#AZRCP2GO"+BE[@EK_/YEY_SL4XO]_@O!<>WCC7'T4^N=_
M*"@G>SC@"GUX2^=\>,C)?WA3*GUH`"'I%#K_?R``^WO"+FA[>-B'?X):*3V9
M>2DY%.HI?8+P/7L42BI]*"AJ>WA#2GTH\"A[>.L=?112*7TXZ.A_(``Z>7A#
MZ'QP`.'H*/!_>\(N2GN"6N<\F7GG.!3RYWR"\'Y[>//^?Q0ZZ'PH*$A[./`_
M?7A3"'UXT*I_>/M??7@`0>D40N=\(`#X>(+P6WO"+@E[>,#(?X):2CV9>4HY
M%.)*?8+P''L44E]]*"@?>WA+_W\H\$E[>-L[?13Z2GTXV.E\(`!9>7A+"7V`
M``'IPBXG>WC(?W^"6@@]F7D(.13J"'T40@E]*"@I>W@[*7TH\`=[>./\?!1*
M"'TXX$=](``:>7@[YW^(`.'K*/`J>\(N27N"6O\_F7G_.Q3R_W^"\#Y[>/->
M?13ZYW\H*$=[./`*?7A+YWQXT(E_>%,J?9``(>D4.O]_(`#]>X+P67O"+JA[
M>.C'?X):*3V9>2DY%-HI?11**GTH**I[>$-*?2CP2'MXRQE]%%(I?3C(Z'\@
M`#AY>$/H?)@`X>B"\+I[*/"]>\(N"GMXT[I_@O`;>X):YSPXT#U]F7GG.!3B
MYWP4.NA\*"@(>WA3"'UXP"I_>.M=?:``0>D40N=\(`#\>,(NB7MXX$A_@EI*
M/9EY2CD4\DI]%%)=?2@HG7MX2[U_*/`)>WC;.WT4ZDI].-CI?"``7GEX2PE]
MJ``!Z<(NQWMX\'U_@EH(/9EY"#D4R@A]@O"9>RCPG'L40@E]>,N9?R@HR7MX
M.RE].,A'?7@[IW^P`*'K%$H(?2``'WEX^"E_PB[\>X):O3^9>;T[%-*]?X+P
MVGLH\-Y[%.JG?WC3VG\H*.=[R`#!ZSC0"GUXX^=\>%,J?;@`(>D4.KU_(`"W
M>]INWC_"+NAZ>+A<?X):*3VAZ]X[F7DI.132WG\4VBE]%$HJ?2@HZGIX0TI]
M9/#H>X+P_WL44BE]>/L(?2``.'G0`.'K(``;><(N"GLXV*=_@O#]>G@[AW_`
M`('KVF[_/Z'K_SL4VO]_@EJ</YEYG#L4RIQ_%.*'?R@H!WMX4^=\9/#J>GCK
M77T4.IQ_>.H*?2``F7MX2DI]PBXH>R``2GDH*"E[%/)*?63P'GN"\!A[>$,I
M?7C#WG\42DI]>/*G?R``6GEXXN=\PBY(>R@H27L@`.=X>$,I?13ZYWS8``'I
M%$KG?&3P*7N"\#E[(`"]>WC+.7W:;@@]>,K)?Z'K"#EX4BI](`#\>!3J"'T@
M`$IYPBZ)>Q12"'TH*(I[9/!;>WA+2GV"\%I[X``AZ7C3>W\44@A](``=>7C:
M*G]X.D=]*"BL>\(NJGO:;BD]>%.,?>@`0>D@`-Y[9/"?>Z'K*3F"\)Q[%/(I
M?7CC_W\@`.=X%#HI?=IN2CUX^F=_%&(I??``@>D@`#E[>$+H?*'K2CD@`#YY
M%,I*?2``"'ED\+Q[@O"]>WCKG'\40DI]*"C'>\(NR'MX0^=\VFZ,/7CBZ'\4
M.DI]^`#AZ"``>WMX2@E]H>N,.2``67D4VHQ](``I>63PW7N"\-Y[>/.]?Q1*
MC'TH*"A[PBXI>WA+"'W:;N<\>.J)?Q1"C'T``0'I(`#_>WA2*GVAZ^<X(`":
M>13ZYWP@`$IY%%+G?"@H27O"+DI[9/`^>X+P.7MX4RE]>,O>?Q1*YWS:;@@]
M>/*I?R``^'@@`)Q[>&(L?:'K"#G"+@E[%.((?2``C'DH*`I[>$M*?11B"'T(
M`2'I9/!;>X+P6GMXTWM_%%((?2``&7EXVLI_>#I'?2@H+'O"+BI[VFXI/7A3
MC'T0`4'I(`"]>V3P'WNAZRDY@O`8>Q3J*7UXP_]_(`#G>!0Z*7W:;DH]>/IG
M?Q1B*7T8`8'I(`#>>WA"Z'RAZTHY(``Z>13R2GT@``AY9/`\>X+P.7MXRYQ_
M%$)*?2@H1WO"+DA[>$/G?-INC#UXXNA_%#I*?2`!X>@@`'M[>$H)?:'KC#D@
M`%AY%-J,?2``*7ED\%U[@O!:>WC3O7\42HQ]*"@(>\(N"7MX2PA]VF[G/'CJ
MB7\40HQ]*`$!Z2``_WMX4BI]H>OG."``F7D4^N=\(`!*>112YWPH*"E[PBXJ
M>V3P'GN"\!A[>%,I?7C#WG\42N=\VFX(/7CRJ7\@`/IX(`"<>WAB+'VAZP@Y
MPBY)>Q3B"'T@`(QY*"A*>WA+2GT48@A],`$AZ63P.WN"\#E[>,M[?Q12"'T@
M`!AY>-K*?W@Z1WTH*`Q[PBX*>]IN*3UX4XQ].`%!Z2``O7MD\%][H>LI.8+P
M6GL4ZBE]>-/_?R``YW@4.BE]VFY*/7CZ9W\48BE]0`&!Z2``WGMX0NA\H>M*
M.2``.7D4\DI](``(>63P''N"\!A[>,.<?Q1"2GTH*"=[PBXH>WA#YWS:;HP]
M>.+H?Q0Z2GU(`>'H(`![>WA*"7VAZXPY(`!:>13:C'T@`"EY%$J,?2@H2'O"
M+DE[9/`]>X+P.7MX2PA]>,N]?Q1"C'U0`0'I>.J)?]INYSP@`)MY(`#_>WA2
M*GVAZ^<XPBYI>Q3ZYWP@`$IY*"A_>V3P7GN"\%I[>-/>?Q12YWQX2_]_VFX(
M/13ZYW]X\JE_6`'AZ"``]WL@`)Q[>&(L?63P>GNAZP@Y@O![>WC;6G_"+NEZ
M%.((?2``C'DH*.IZ%&((?7A+2GW:;B<]>-+'?Q12"'T@`+U[>/KG?*'K*3D@
M`!EY%.HI?2``YW@4.BE]*"@J>\(N)WMD\/MZ>#M*?8+P]WH44BE]8`%!Z7B[
M>W]XVD=_(`#>>WA"Z'P@`#AYVFY*/2``"'FAZTHY9/`\>Q3R2GV"\#E[>,N<
M?Q1"2GTH*`=[PBX(>WA#YWQXXVA_.$@(?3C@:7\4.NI\>$L(?6@!(>D;CT`]
M(`#_>-R\2F%D\!U[(`!*>8+P&'L42BI](`!:>WC#O7\4TDE_*"CL>\(NZ7L@
M``AY>$N,?132"'UXZXE_%&*(?3@X*7TXZ(A_(`"9>7A#*7UP`0'I9/#^>R``
M>WN"\/][>/O>?R@H)WL40@I](``I>13::'_"+BA[%-HI?7A#YWQX\ZA_%#KI
M?#A@"'TX\*E_>$L(?7@!(>D@`/IX9/`_>R``G'N"\#E[*"A,>Q1**GUXR_]_
M%.*)?R``"'G"+DE[%.((?7A+C'UX^\E_%&*(?3@X*7TX^,A_(`"8>7A#*7V`
M`0'I9/!;>R``O7N"\%I[>--[?R@H!WL40@I](``I>13JJ'_"+@A[%.HI?7A#
MYWQXV^A_%#KI?#A@"'TXV.E_>$L(?8@!(>D@`/EX9/`<>R``WGN"\!A[*"@L
M>Q1**GUXPYQ_%/+)?R``"'G"+BE[%/((?7A+C'UXXVE_%&*(?3@X*7TXX&A_
M(`":>7A#*7V0`0'I9/`]>R``_WN"\#E[>,N]?R@H1WL40@I](``I>13ZZ'_"
M+DA[%/HI?7A#YWQXZXA_%#KI?#A@"'TXZ(E_>$L(?9@!(>D@`/AX9/!>>R``
M>WN"\%I[*"@,>Q1**GUXT]Y_%-II?R``"'G"+@E[%-H(?7A+C'UX\ZE_%&*(
M?3@X*7TX\*A_(`"9>7A#*7V@`0'I9/`?>R``G'N"\!A[>,/_?R@H)WL40@I]
M(``I>13BB'_"+BA[%.(I?7A#YWQX^\A_%#KI?#A@"'TX^,E_>$L(?:@!(>D@
M`/IX9/`[>R``O7N"\#E[*"A,>Q1**GUXRWM_%.JI?R``"'G"+DE[%.H(?7A+
MC'UXV^E_%&*(?3@X*7TXV.A_(`"8>7A#*7VP`0'I9/!<>R``WGN"\%I[>-.<
M?R@H!WL40@I](``I>13RR'_"+@A[%/(I?7A#YWQXXVA_%#KI?#A@"'TXX&E_
M>$L(?;@!(>D@`/EX9/`=>R``_WN"\!A[*"@L>Q1**GUXP[U_%/KI?R``"'G"
M+BE[%/H(?7A+C'UXZXE_%&*(?3@X*7TXZ(A_(`":>7A#*7W``0'I9/`^>R``
M>WN"\#E[>,O>?R@H1WL40@I](``I>13::'_"+DA[%-HI?7A#YWQX\ZA_%#KI
M?#A@"'TX\*E_>$L(?<@!(>D@`/MX9/!?>R``G'N"\%I[*"AL>Q1**GUXT_]_
M%.*)?R``"'G"+FE[%.((?7A+C'UX^\E_%&*(?3@X*7TX^,A_(`"<>7A#*7W0
M`0'I9/!Z>R``O7N"\'M[>-M:?R@HAWL40@I](``I>13JJ'_"+HA[%.HI?7A#
MYWQXT^A_%#KI?#A@"'TXT.E_>$L(?=@!(>D@`/UX9/";>R``WGN"\)Q[*"BL
M>Q1**GUXXWM_%/+)?R``"'G"+JE[%/((?7A+C'UXVTE_%&*(?3@X*7TXV$A_
M(`">>7A#*7W@`0'I9/"\>R``_WN"\+U[>.N<?R@HQWL40@I](``I>13ZZ'_"
M+LA[%/HI?7A#YWQXXVA_%#KI?#A@"'TXX&E_>$L(?>@!(>D@`/AX9/#=>R``
M6GN"\-Y[*"@,>Q1**GUX\[U_%-))?R``"'G"+@E[%-((?7A+C'UXZXE_%&*(
M?3@X*7TXZ(A_(`"9>7A#*7WP`0'I9/`>>R``>WN"\!A[>,/>?R@H)WL40@I]
M(``I>13::'_"+BA[%-HI?7A#YWQX\ZA_%#KI?#A@"'TX\*E_>$L(??@!(>D@
M`)Q[(`#[>"``"'G"+G][(`"]>Q1**GT4XHE_*"AI>Q3B"'UD\#Q[@O`Y>WC[
M*7UXRYQ_%$H(?7CCR7\@`!IY.#@I?3C@QW]X.RE]``+AZ`@"X>L@`-Y[(``I
M>10Z2GW"+D=[%.I*?11227TH*$E[>#LI?11*2GUD\&E[@O![>R``5WEXVSM]
M8LH@/=;!*6%XVH=_(``I>7A"Z'P4^NE_(``(>13R_W_"+N=Z%$+_?R@HZ'IX
M.PA]$`+AZ"``G'L40O]_9/!(>X+P6GL@`/E[>-,:?10ZZ7QXTFA_%.+G?'A2
M"GW"+BA[(`!*>63P_7H44N=\*"@J>WA#2GV"\/=Z&`(!Z7B[O7\44N=\(`#X
M>'CJ2G]X^E]]*"@,>\(N"GL40@E]>%.,?2``>WL@`D'I9/`^>X+P.7MXR]Y_
M%-H(?2``_WL44DE]%/H(?7CROW\48@A](`!:>R@"@>EX.N=_(``<>1322GT@
M`.=X9/`:>X+P&'MXPUI_%#I*?2@HGWO"+H=[>#O_?WC2QW\4^DI]%&*)?3`"
MX>L@`+U[>$+H?"``67D4ZHQ](``(>63PFWN"\)Q[%$*,?7CC>W_"+BA[*"@G
M>Q3ZZ7]X0^=\>-I(?Q0ZC'T@`-Y[.`+AZ'A2"GT@`)=Y%/+_?R``2GD44O]_
M*"CH>L(NZGID\#Q[@O`Y>WA3"'UXRYQ_%$+_?WCB:G\@`/A[%#KI?"``6GMX
M8DQ]PBX(>Q32YWP@`(QY*"@*>Q1BYWQX0TI]9/#]>D`"`>F"\/=Z%%+G?'B[
MO7\@`/EX>.J*?R@H+'MX^E]]PBXJ>WA3C'T40@E]2`)!Z2``>WMD\!Y[@O`8
M>Q3:"'UXP]Y_(`#_>Q3Z"'UX\K]_%&((?11227U0`H'I(`"<>W@ZYW\@`!=Y
M%.)*?2``YWAD\#I[@O`Y>Q0Z2GUXRUI_PB[G>B@H_WH48HE]>#O_?WC2QW\4
M^DI](`"]>U@"X>MX0NA\(`!8>13JC'T@``AY9/#[>H+P]WIXNWM_%$*,?2@H
M!WO"+@A[>$/G?'C:2'\4.HQ]%/KI?V`"X>@@`-Y[>%(*?2``F7D4\O]_(`!*
M>2@H*'L44O]_9/`<>\(N*GN"\!A[>,.<?WA3"'T40O]_>.)J?R``]WL4.NE\
M(`!:>WAB3'W"+NAZ%-+G?"``C'DH*.IZ>$-*?11BYWQH`@'I9/`]>X+P.7MX
MR[U_%%+G?"``^'AXZHI_>/I??2@H#'O"+@I[%$()?7A3C'T@`'M[<`)!Z63P
M_GJ"\/=Z>+O>?Q3:"'T@`/][%%))?13Z"'UX\K]_%&((?2``G'MX`H'I>#KG
M?R``&7D4XDI](`#G>&3P&GN"\!A[>,-:?Q0Z2GTH*#][PBXG>W@[_W]XTL=_
M%/I*?11BB7V``N'K(`"]>WA"Z'P@`%=Y%.J,?2``"'ED\#M[@O`Y>Q1"C'UX
MRWM_PB[H>B@HYWH4^NE_>$/G?'C:2'\4.HQ](`#>>X@"X>AX4@I](`"8>13R
M_W\@`$IY%%+_?R@H"'O"+@I[9/#\>GA3"'V"\/=Z%$+_?WB[G'\@`/E[>.)J
M?\(N*'L4.NE\(`!:>WAB3'TH*"I[%-+G?'A#2GUD\!U[D`(!Z2``C'F"\!A[
M>,.]?Q1BYWP44N=\>.J*?Q1""7UX^E]](`![>R``^G@@`/][%-H(?13Z"'W"
M+DI[*"A?>V3P/GMX4_]_F`)!Z8+P.7MXR]Y_(`"<>Q3ZZ'\46GY]%%))?2``
MZ'L4XDI]>/*\?W@ZAW_"+AQY(`#G>"``O7L4.DI]*"@'>7CCYWR"\!QY%#I*
M?63P1WN"\%I[(`!*>7C3^GR@`N'H*/`(>7CC"'T4(II\%"JH?"``A'@4.BE]
M>-+'?WCZ_WP4ZBE]&`"#^"``_WLH*$=Y%/HI?<(N7WEX^^=\%%)&?10Z*7T@
M`$IY%`(I?2``I7@@`"EY(`!K>0@`0_D0`*/X```C^2``8_FH`D'I\(\MZ7E*
M2GT``"`Y#`""0;G<_TL8`$'H``,A.$P>`$@``````````8`)```"`$P\O$)"
M.*8""'P!'@!(>1M\?+'_(?@``,`[(`""00```&`X@"+I``#`.WCCA7\``*GK
M``"]+QP`GD!0`"$X>//#?P0>`$@]`(DK%`">00$`I3@``"6)``"I+^S_GD!0
M*+Q\>".:?+0'OWQXZ[M_``#;ZP``OB_$_YY!>/OE?WCCA']X\\-_->+_2Q@`
M0>@``*,O*`">0*[X/GT]`(DO'`">0%#8O7\!`/\[=!Z]?Q3ZWG\``+J3A/__
M2P@`>SNP__]+``````````&`!@```@!,/.Q!0CBF`@A\$``!^)'_(?AD`($X
M\(\MZ6@`(?D``"`Y%?__2V@`0>GPCRWI>4I*?0``(#D,`()!D=O_2Q@`0>AP
M`"$X$``!Z*8#"'P@`(!.``````````&``````@!,/(Q!0CBF`@A\\/_!^_C_
MX?MX&W]\$``!^('_(?CPCRWI:``A^0``(#ED`,$[>//$?WC[XW^A_O]+``"C
M+R``GD!H`"'I\(]-Z7E2*7T``$`Y/`""017;_TL8`$'H9@`AZ0```&`X@`+I
M)!\I>?C_23D``"CI%%(I?1``2>D``*HO"0!)^?3_GD"D__]+@``A.*@<`$@`
M`````````8`"```"`$P\Z$!".*8""'PI'`!(4?\A^'@;?7SPCRWI:``A^0``
M(#D``"2)/0`I:30`*7U^V2E5%$KD?WC[XW\-X?]+&`!!Z&0`@3AX&WQ\>.NC
M?^7]_TMY&WY\3`""0>W@_TL8`$'H0!B\?_0`G4'___\[___>.P$`/XT``*DO
M`0`^G?3_GD```&`X:`!!Z?"/+>EY2DI]```@.7`!@D$MVO]+&`!!Z````&`X
M@&+K``#`.P``6^OX_UHY"0`JZ0``J2]``)Y`````8+B!(H$"`)XX``")+S@`
MGD&T!X1\>--#?R0?A'AEW_]+&`!!Z```HR\``'OX4`">0/__8#B,__]+`0#>
M.[0'WG^P__]+`0`@.0```&"T!X1\)!^#>+B!(I'IWO]+&`!!Z'D;>7S,_X)!
M)!_%>WC31'_1V_]+&`!!Z```._L!`#XY``!;Z0```#DD'REY*DD*?60`P9-X
MZZ-_```CB0``J2^``)Y`9@#!ZP```&`X@&+K4!A]?`(`G#NT!V-\%.)C?```
M6^M]WO]+&`!!Z"0?WGL``*,O*O%Z?%C_GD%F`"'I``!;Z?__O3LD'REY*D@J
M?0$`78T``*HO``!)F30`GD`]`$`Y____.P``29D!`%^-``"J+P$`29WT_YY`
MH/[_2ST`B2N`_YY!`0!C.&S__TL]`(HKS/^>00$`*3FT__]+L``A.&0:`$@`
M`````````8`'```"`$P\S#Y".*8""'P)&@!(P?XA^'D;?7SPCRWI^``A^0``
M(#EH`()!```]B0``B2]<`)Y!F=S_2Q@`0>AY&WQ\3`""0?[_8C_^_T(__O\B
M/U7=>SM4W5H[5]TY.V@``3MXXX-_R=C_2Q@`0>AY&W]\.`""0'CC@W_UVO]+
M&`!!Z'CKHW])W?]+&`!!Z/@`0>GPCRWI>4I*?0``(#G4`()!#=C_2Q@`0>@3
M`/\[>-MD?WC[XW_9W/]+&`!!Z```HR^@_YY!>--$?WC[XW_!W/]+&`!!Z```
MHR^(_YY!>.NC?TW>_TL8`$'H>!M^?'C[XW\]WO]+&`!!Z!3R8WP"`&,XM`=C
M?.G<_TL8`$'H>/OF?WCKI7]XRR1_>!M^?'';_TL8`$'H>,,$?WCSPW_!VO]+
M&`!!Z/__@R]X\\-_*`">08``(8$F!"E5`$")+Q@`GD"Y_O]+>//#?Y78_TL8
M`$'H`/__2PG>_TL8`$'HZ/__2T`!(3C<&`!(``````````&`"````@!,/$@]
M0CBF`@A\^/_A^W@;?WP0``'X,?\A^"@`@3CPCRWIN``A^0``(#F]W/]+&`!!
MZ```(RQ4`()`0``A@28$*54`0(DK$`">0?__*FT`H(HO'`">0`(`@#AX^^-_
M2=G_2Q@`0>@T`&-\?MEC5+@`0>GPCRWI>4I*?0``(#D4`()!I=;_2Q@`0>@`
M`&`XX/__2]``(3AD&`!(``````````&``0```@!,/*`\0CBF`@A\````8$"`
M(ND0``'XX?\A^```:8`!V/]+&`!!Z````&!(@*+H_O_"//[_@CPHW<8X7=V$
M.*'8_TL8`$'H(``A.!```>BF`PA\(`"`3@`````````!@`````(`3#P\/$(X
MI@((?/C_X?L```!@0(#BZQ```?C1_R'X``!_@)G7_TL8`$'H>?__2P``?X")
MU_]+&`!!Z/[_XCS^_Z(\Z=_G./[_@CP````Y>#OF?"S6I3AYW80XP=S_2Q@`
M0>@P`"$XB!<`2``````````!@`$```(`3#S$.T(XI@((?!47`$AAWR'X\(\M
MZ7@@(?D``"`Y9=C_2Q@`0>AH`.$[_O_"//[_@CQX&V5\CMW&.)+=A#AX^^-_
M0=G_2Q@`0>@``(,O*`"<0```P#MX($'I\(\MZ7E*2GT``"`Y>//#?V0`@D$U
MU?]+&`!!Z'`0H3MX^^-_`!"@.'CKI'\=U_]+&`!!Z+0'?WP``)\OO/^<00$`
M?SBT!V-\0=K_2Q@`0>AY&WY\J/^"07C[Y7]XZZ1_2=S_2Q@`0>@``"`YKOD^
M?8S__TN@("$XB!8`2``````````!@`,```(`3#S@.D(X'/__2P``````````
M``````(`3#S(.D(XI@((?":`D'T(`(&1[14`2*'N(?AX&WY\_O]B/)[=8SAX
M(Y]\\(\MZ?@0(?D``"`YK?C_2R\`@#AX&WI\>//#?R'8_TL8`$'H``"C+S0`
MGD'^_V(\>//$?Z?=8SB%^?]+^!!!Z?"/+>EY2DI]```@.7CSPW]X`8)!*=3_
M2Q@`0>AX\\-__O^"/YG:_TL8`$'HM-V<._[_(C]XXX1__O_B/K0'>WQX^^-_
MF=?_2Q@`0>C^_\(^``"`.@``.BY5W3D[>!M_?````#L!`'L[MMWW.I+>UCKX
M`*$[:`"A.@"`E&(``+\O;/^>00``/XD``(DO"`">0'C+/W\@`))!>/OD?WC3
M0W]]V/]+&`!!Z'CCA'\``*,OR`">07C[XW\%VO]+&`!!Z+0'8WP4&C]]__\I
MB2\`B2^0`)Y!%!I[?/\/@R\0_YU!>//'?WB[YGYX^^5_>+/$?GCKHW\IU_]+
M&`!!Z'BKI'YXZZ-_>=;_2Q@`0>@``*,O8`">0(``(8$F!"E5`*")?U``GD`!
M`(`X>.NC?Y'5_TL8`$'H``"C+S@`GD#^_V(\>.ND?Z?=8S@U^/]+>.NC?VW4
M_TL8`$'H>!M^?*#^_TO__V,XM`=C?*X9'W]8__]+>..$?P``8#AEUO]+&`!!
MZ'@;?WSX_O]+8!$A.`@`@8$@@9!]/!0`2``````````#@`P``/__0SD!`"J)
M`0`*.0``J2\(`)Y`(`"`3B\`B2L(`)Y``@!J.'A#"GW<__]+````````````
M`````@!,/(`X0CBF`@A\^/_A^WD;?WSP_\'[$``!^-'_(?@0`()!``#?BP``
MOB\<`)Y`_O]B/%7=8SBIT_]+&`!!Z#``(3CL$P!(F=C_2Q@`0>C__R,Y%$J_
M?'@;:7P4&G]\__]C.$`8OW\,`)U!__^_+P@`GD`!`"`Y`0`I+/__*3FL`()!
M``!%B2\`BB^(`)Y!__]%.5`H/WU`4+]_"`"=0`$`(#D``$6)+P"*+W``GD#_
M_T4Y4"@_?4!0OW\,`)U!__^_+P@`GD`!`"`Y`0`I+/__I3C__RDY<`""0%`H
MOWP``&`X`@`E.0`0J2M4_YU!````8`$`I3C`@<([>/OD?WCSPW^]TO]+&`!!
MZ'CSPW\P__]+__^E.&#__TL!`"DL__^E./__*3E\_X)`0"B_?X#_GD`O`)XK
M^/Z>0?[_8CRVW6,X]/[_2P``18DO`(HO?/^>08C__TL``````````8`"```"
M`$P\'#=".*8""'S^_T(]*-U*.?[_8CRXW6,X61(`2%'_(?C^_\(__O^B/]G=
MWCN>W;T[_O_B/_[_@C_UW?\[_]V<._"/+>F(`"'Y```@.0H`*CD``,GH"`#I
MZ!``">D8`$GI(``IH6``P?AH`.'X<``!^7@`0?F``"&Q'?7_2_[_8CS!W6,X
M$?7_2_[_8CS)W6,X!?7_2_[_8CS2W6,X^?3_2WCSPW_Q]/]+_O]B/.G=8SCE
M]/]+>.NC?]WT_TMX^^-_U?3_2WCC@W_-]/]+_O]B/`G>8SC!]/]+_O]B/*?=
M8SBU]/]+_O]B/!/>8SA)]/]+>1MD?`P`@D%XXX-_/?7_2_[_8CPDWF,X+?3_
M2WD;9'P0`()!_O]B/#;>8S@=]?]+_O]B/$'>8S@-]/]+>1MD?#@`@D%XZZ-_
M`?7_2_[_@CQX\\-_;=Z$./'T_TN(`$'I\(\MZ7E*2GT``"`Y4`""09G/_TL8
M`$'H_O]B/%'>8SC%\_]+>1MD?`P`@D%X^^-_N/__2_[_@CP*`*`X8MZ$.'$`
M83B%U?]+&`!!Z```HR^<_YY`>P"!.-3__TNP`"$X_!``2``````````!@`0`
M``(`3#Q8-4(X````8`B!(H'__XDO8`">0*8""'S^_V(\]=UC.!```?BA_R'X
M2?/_2P``0#D``",L'`""00``(XD``*DO$`">03``*6G__TDQ$$E*?6``(3@`
M``!@$``!Z`B!0I$```!@I@,(?`J!8N@@`(!.````8`J!8N@@`(!.````````
M``&``````@!,/,PT0CBF`@A\$``!^.'_(?B9S_]+&`!!Z/'._TL8`$'H```C
M+!P`@D$``"/I(``A.'A+(WT0``'HI@,(?"``@$X``"`YZ/__2P`````````!
M@`````(`3#QT-$(XI@((?,$/`$B!_R'X_O_"/W@;?WQOWMX[>//#?VWR_TMX
M^^1_>1M]?!``@D$``#V)``")+Q0`GD!X\\-_4?/_2X``(3B\#P!(1=+_2Q@`
M0>@``*,O[/^>0'C[XW]QU/]+&`!!Z'@;?'QXZZ-_8=3_2Q@`0>@4&GQ\`@!C
M.!'3_TL8`$'H_O_"//[_@CR2WH0X>.NG?W@;?'RTW<8X>/OE?XW1_TL8`$'H
M>..$?XS__TL``````````8`$```"`$P\L#-".*8""'P```!@$($"Z0```&`8
M@4+I````8""!(NG!#@!(__\`//[_0C_@?0!@GMU:.W@;>'QXTT-_:@$A?+"!
MX3L!`,$\\(_MZ*B!YO@``.`X````8"B!XNC`?A_YR'Y?^0```&`P@0+I````
M8#B!0NG0?C_Y````8$"!(NGP?O_X^'X?^0!_7_D(?S_Y````8$B!0ND```!@
M4($BZ0```&!8@0+I$']?^1A_/_D```!@8(%"Z0```&!H@2+IV'X?^>!^7_GH
M?C_Y_?#_2WD;?GQ(`()!```^B0``B2\\`)Y!7?[_2WCSPW\ASO]+&`!!Z'@;
M?'P!`,$\>..#?ZB!YNCPC\WH>3+G?```P#BT"()!><S_2Q@`0>C-_?]+>1M^
M?-0!@D%X\\-__O]B/]W2_TL8`$'H___>.X;>>SND#V-X`0!C.(71_TL8`$'H
M>!M\?'@;?7P!`+Z,``"E+Z0!GD```,`[\'Y_.RK8OG\``+TO/`">07CKHW]-
M\/]+>1M]?)@!@D$``#V)``")+XP!GD'9]/]+``"C+X`!GD%XZZ-_:<W_2Q@`
M0>AX&WU\``!@.\!^/SL``+TO'`">0"K(VW\``+XO$`">00``/HD``(DO4`&>
M0'CKHW_^_R(_+=+_2Q@`0>BVW3D[>!M^?'CC@W\9TO]+&`!!Z!3RPW\$!-X[
MM`?>?WCSPW_!T/]+&`!!Z/[_XCS^_X(\>..(?XO>YSAXRR9_>.NE?Y#>A#AX
M&WM\.<__2Q@`0>C``8`X>-MC?^G+_TL8`$'H__^#+_P`GD`YSO]+&`!!Z```
M(X$1`(DOZ`">00```&!0@"+I``#XZP``*>EH`"'Y$<[_2Q@`0>C^_X(\>-MF
M?WC[Y7^9WH0X`@#CZ&@`8>BQS/]+&`!!Z```@#M0_O]+'>__2P``P#MY&VE\
M'`""00``*8D``(DO$`">047,_TL8`$'H>!M^?```OB\(`+T[3/Z>0"K@?7P`
M`*,OQ/^>0/[_PC]_WMX[-/[_2P``H#O8?I\[X/__2WCKHW]XVV1_8<[_2Q@`
M0>@"`+T[0/[_2P@`WCM,_O]+>//#?T7S_TL``*,O%`">07CSPW_5R_]+&`!!
MZ'@;?7P(`'L[</[_2R!_GSAXVV-_^<__2Q@`0>AY&WU\/`:"0#A_/X$F!"E5
M`$")+RP&GD`\?Y^#%<O_2Q@`0>@`X(-_&`:>0#A_/X'^!2E5P`&)+P@&GD!X
M\\-_,<__2Q@`0>AX&WQ\_O]B/'K>8S@9[O]+``"C+R0`GD$``-CK3<O_2Q@`
M0>AX&V1\>//#?QWU_TMY&W=\"`""0```^.IXN^-^*=#_2Q@`0>BT!WY\`P">
M+X@`G4#\_WXX_O^"/-3>A#@4&G=\9<[_2Q@`0>@``*,O:`">0`0`GB\<`)Y!
M_/_>.[0'WG\4\M=___\^B2\`B2](`)Y`"`#8ZP``OB\\`)Y!>//#?\7/_TL8
M`$'H`P"C*R@`G4#\_V,X_O^"/-G>A#@4&GY\!<[_2Q@`0>@``*,O"`">0'CS
MUW_A^?]+``"C+V0$GD```(`X>+OC?CW/_TL8`$'H>1MX?$P$@D$"`*`X[O^`
M.(7/_TL8`$'H^'_?.P8`H#AX\\1_>,,#?ZW*_TL8`$'H^'\_B0``B2^T`)Y`
M^7\_B4,`B2^H`)Y`^G\_B4$`B2^<`)Y`^W\_B4,`B2^0`)Y`_'\_B4@`B2^$
M`)Y`_7\_B44`B2]X`)Y``@"@.,;_@#AXPP-_$<__2Q@`0>@I`*`X>//$?WC#
M`W\]RO]+&`!!Z/[_`CUX\\=_Z=\(.?[_@CQXRR9_>-ME?][>A#AXXX-_%<S_
M2Q@`0>AXVV-_:<G_2Q@`0>AXXX1_>--#?UGM_TMXXX-_Q?G_2WC[_TL``*`X
M``"`.'C#`W___Z`ZF<[_2Q@`0>A%9R`]^'_?.@$C*6$@!+56('^?.EA_?SH@
M?S_YS>\@/8FK*6$@`"EY*'\_^;J8(#W^W"EA(``I>3!_/_DR$"`]=E0I83A_
M/_G2PR`]\.$I82``*7E`?S_Y```@.4A_/_E0?S_YF'\_D7BKI7YXL\1^>,,#
M?UW)_TL8`$'HM`=]?```G2^D`9U!>,,#?UA_'SLAS/]+&`!!Z$A_W^N`_T`Y
M4'^_ZZ+NQ7NT!ZE\`0"E.#@`A2^T!Z-\KDE8?10:>'Q\`IU`0`"E(```@#BT
M!Z5\('__.KW,_TL8`$'H>+OC?D'4_TLX`*`X``"`.'C#`W^AS/]+&`!!Z`)&
MJ7L@?W\XDW^_FY=_WYO^_P(_L'__.I!_/YD"A*E[AMX8.Y%_/YD"PJE[R'^_
M.Y)_/YD"1LE[E'\_F0*$R7N5?S^9`L+)>P``P#N6?S^9V=/_2R!_/^D"1BIY
MLW\_F;!_7YD"A"IYL7]?F0+"*GDH?S_ILG]?F0)&*GFW?S^9M']?F0*$*GFU
M?U^9`L(J>3!_/^FV?U^9`D8J>;M_/YFX?U^9`H0J>;E_7YD"PBIY.'\_Z;I_
M7YD"1BIYOW\_F;Q_7YD"A"IYO7]?F0+"*GE`?S_IOG]?F0)&*GG#?S^9P']?
MF0*$*GG!?U^9`L(J><)_7YFN\+=\I`_#>WC#!'\4&GU\`0#>.]')_TL8`$'H
M%`"^*^#_GD```"`Y_O\"/>G?"#EXZZ=_\'\_F83]_TM(?U_I)!^I>Q12*7T@
M`"EY0$BJ?Q``G4!0?U_I`0!*.5!_7_F:?W_H4']?Z4A_/_E"'ZE[``"C+Q1*
M*GU0?S_Y7`">04``(R%XZ[=_`$B=?P@`G4!X2S=]M`?^?GBSQ'YX\\5_%!IS
M?,',_TL8`$'HF'\_@12Z*7U``(DOF'\_D<#]GD!0Z+=_%/+6?[0'O7]XHX-^
M9=+_2P@``$CX?]\[/P"=+R``G4%XZZ5_>//$?WB;8WYUS/]+&`!!Z)A_OY.`
M_?]+``#^Z`@`'ND0`%[I&``^Z<#_O3M``-X[M`>]?UA___A@?Q_YX/_^Z.C_
M'NEH?U_Y<'\_^?#_7NGX_S[I>'__^(!_'_F(?U_YD'\_^8#__TLX`*4@``"`
M.+0'I7RH_?]+_O^"//[_8CQMWH0X]=UC.-7I_TO^_^(__O_"/^G?_SO[WMX[
M8<?_2Q@`0>C^_X(\>/OH?WC+)G]XVV5_>!MG?.W>A#AXXX-_/<C_2Q@`0>C`
M`8`X>..#?^W$_TL8`$'H__^#+Q3\GD`]Q_]+&`!!Z```(X$1`(DO`/R>0`G'
M_TL8`$'H`0"].WC[Z7^T![U_>,LF?W@;9WQXZZA_>-ME?WCSQ']XXX-_W<?_
M2Q@`0>B@__]+````8%"`(ND``+CH_O^"/'C;9G\,WX0X``!IZ)7%_TL8`$'H
MY/C_2P``(>A4!0!(``````````&`#0```@!,/-0I0CBF`@A\$04`2&'_(?@`
M``!@0(#BZP``?X`UQ?]+&`!!Z'@;?GP``'^`)<7_2Q@`0>BX`".)_O]B/-G=
M8SBY`#Z9J>?_2P``(RP<`()!```CB3$`B2\0`)Y``0`CB0``B2\(`)Y!5?+_
M2P``?X````!@N('".]G$_TL8`$'H_O^"/`L`P#@!`*`X7]^$.$'&_TL8`$'H
M```C+)0`@D```'^`K<3_2Q@`0>C^_X(\`P#`.`$`H#ADWX0X%<;_2Q@`0>AY
M&WU\:`&"0```?X"!Q/]+&`!!Z/[_@CP#`,`X`0"@.&O?A#CIQ?]+&`!!Z'D;
M?7S,`8)!_O]B/*?=8SCMYO]+>1M\?(`!@D$``'^`0<3_2Q@`0>@0`#WI>..%
M?P``B>C-PO]+&`!!Z)0!`$@0`"/I(```/P``H#L`!!AC*`!)ZP@0/H$!`)T[
MM`>;?P#@B7\L`)U```!_@/7#_TL8`$'H``#`.'CKI7]XTT1_H<;_2Q@`0>AY
M&WE\3`""0````&#`D2*!__\I.0#HB7\0_YY``0"@.P@0/H$`Z(E_`/^=0```
M?X`!`+T[M`>]?Z'#_TL8`$'H>--$?]7(_TL8`$'HU/__2Q`0/ND``%GI)!][
M>RK8:7\,`"J!.$@)?P`$B2\D`)Y`$`"*Z'C;8W^AQO]+&`!!Z```HR^$_YY`
MM`>=?T#__TL``'^`1</_2Q@`0>@``)GH`@#`.```H#BQP_]+&`!!Z'@;9'S`
M__]+``!_@!W#_TL8`$'H$``]Z?[_HCQFWZ4X``")Z*7!_TL8`$'H$``]Z0``
M*>D,`"F!0``J=6C^@D$``'^`Y<+_2Q@`0>@0`#WI``")Z)7&_TL8`$'H2/[_
M2XWK_TMY&WQ\``!_@-``@D&YPO]+&`!!Z!``/>EXXX5_``")Z$7!_TL8`$'H
M>..#?SG"_TL8`$'H``!_@(W"_TL8`$'H>!M]?```?X!]PO]+&`!!Z/[_@CP!
M`*`X;=^$..G!_TL8`$'H_O^B/(+?I3AX&V1\>.NC?_'`_TL8`$'H``!_@$7"
M_TL8`$'H```@.;D`(YG^_V(\GMUC.,GD_TL```!@``"C+]"18OA,`)Y`````
M8,B18NCI\O]+````8```HR_0D6+X,`">0/[_8CR(WV,XE<?_2Q@`0>CMP?]+
M&`!!Z````&#(D4+I$``]Z0``JNBD_?]+````8-"18NC``8`XQ<#_2Q@`0>@1
M`(,O>!MF?"P`GD$!`",Y`0")*R``G4`0$#[I&!"^Z/[_8CRIWV,X``")Z#''
M_TL8`$'HH``A.(@!`$@``````````8`(```"`$P\]"5".*8""'SP_\'[^/_A
M^W@;?GP0``'XD?\A^%WM_TL9[?]+>!M_?'GP_TL``*,O4`">00``OB](`)Y!
M```^B0``B2\\`)Y!_O^"/'C[XW^+WH0XO</_2Q@`0>@`&+]_(`">0'``(3AX
M\\-_$``!Z/#_P>OX_^'KI@,(?+#F_TMP`"$X'`$`2``````````!@`(`````
M`&````!@````8````&````!@````8````&`"`$P\0"5".*8""'S__R(]('PI
MZ?C_X?O__^(_('S_.___J2\0``'XT?\A^#0`GD$```!@````8````&```$)@
MI@,I?7A++'T8`$'X(02`3A@`0>CY_S_I__^I+^3_GD`P`"$X$``!Z/C_X>NF
M`PA\(`"`3IC_8?J@_X'ZJ/^A^K#_P?JX_^'ZP/\!^\C_(?O0_T'[V/]A^^#_
M@?OH_Z'[\/_!^_C_X?L0``'X(`"`3IC_8>J@_X'JJ/^AZK#_P>JX_^'JP/\!
MZ\C_(>O0_T'KV/]AZ^#_@>L0``'HZ/^AZZ8#"'SP_\'K^/_AZR``@$[P_\'K
M$``!Z/C_X>NF`PA\(`"`3@```&`PH@$``````*8""'P%`)]"I@)H?1@`0?CP
M_TOHI@,(?%!@BWT46F)]T/\,.```B^F"\`!XI@.)?0@`:^D@!(!.R/__2\3_
M_TO`__]+O/__2[C__TNT__]+L/__2ZS__TNH__]+I/__2Z#__TN<__]+F/__
M2Y3__TN0__]+C/__2XC__TN$__]+@/__2WS__TMX__]+=/__2W#__TML__]+
M:/__2V3__TM@__]+7/__2UC__TM4__]+4/__2TS__TM(__]+1/__2T#__TL\
M__]+./__2S3__TLP__]++/__2RC__TLD__]+(/__2QS__TL8__]+%/__2Q#_
M_TL,__]+"/__2P3__TL`__]+_/[_2_C^_TOT_O]+\/[_2^S^_TOH_O]+Y/[_
M2^#^_TO<_O]+V/[_2P(`3#P$(T(XI@((?!```?CA_R'X6<C_2P```&`@`"$X
M$``!Z*8#"'P@`(!.<&5R;'AS:2YC`%]?14Y67U!!4E]#3$5!3E]?("`@("`@
M("`@("`@("`@```N+@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D
M97(`26YT97)N86QS.CI005(Z.D)/3U0`97AE`"]P<F]C+R5I+R5S`%!!4E]4
M14U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]0
M5`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!
M3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,
M3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,
M3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0051(`%-94U1%
M30`E,#)X`'!A<BT`)7,E<R5S)7,`)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@
M<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@!P87)L`"YP87(`
M)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S
M`"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S
M92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`05)'5@`8
M`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`T-0!5;F%B;&4@=&\@
M8W)E871E(&-A8VAE(&1I<F5C=&]R>0`E<SH@8W)E871I;VX@;V8@<')I=F%T
M92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`"UE
M`"TM`%5315(`55-%4DY!344`5$5-4$1)4@!435``+W1M<`!E=F%L("=E>&5C
M("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@
M<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY
M("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H
M)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P
M9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T
M<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&
M:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@
M?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T
M96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE
M.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L
M"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W
M:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF
M(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q
M"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE
M("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]
M("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E
M("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE
M;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I
M9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?
M:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@
M)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_
M("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I
M;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^
M("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?
M<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@
M)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*
M;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(
M*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S
M970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]
M("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T
M+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=
M.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q
M6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A
M9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN
M(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@
M)&]F9G-E="`^(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N
M;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(
M+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M
M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U
M9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E
M7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U
M9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D
M9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L
M;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M
M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E
M>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\
M:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&-R8R1E
M>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L
M;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F
M:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@
M;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM
M>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D8G5F
M+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92![
M"B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U
M;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C
M<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T
M.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]
M($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F
M:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O
M('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE
M>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*
M9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*
M?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA
M;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H
M)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP
M9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE
M;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE
M;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC
M<F-]+G!M(BP@)&9I;&5N86UE+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L
M("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2([
M"F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I
M;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD[
M"G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*
M=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES
M="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE
M(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@
M>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N
M;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID
M96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S
M("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(
M*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO
M9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5]
M.R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M
M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T
M87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H
M:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@
M("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*
M=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G
M+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@
M/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO
M=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]
M?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@
M97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E
M<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2![
M"G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2![
M"B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G
M<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<[
M"GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D
M,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8
M.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2![
M"B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M
M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT[
M"FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z
M.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T
M;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD[
M"FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS
M971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R
M(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H
M*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII
M<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A
M<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@
M;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T
M82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M
M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`]
M(%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@
M;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES
M(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B
M.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W
M*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/
M3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D
M(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<
M)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R
M(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA
M<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME
M>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L
M(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@
M(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!
M4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC
M*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L
M96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@
M/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E
M<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]
M"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG
M.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]
M*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S
M("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1]
M.PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM
M>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF
M("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE
M(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI
M7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L
M<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@
M)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I
M<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA
M<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D
M=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A
M8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*
M<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\
M)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO
M9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL
M92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z
M<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M
M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R
M:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^
M<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I
M;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#
M4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]
M"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C
M:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A
M8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM
M>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ
M4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[
M($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T
M.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@
M979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA
M7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I
M('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E
M('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM
M;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]
M"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM
M93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H
M95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D
M8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M
M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD[
M"B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T
M('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*
M<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I
M;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O
M9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D
M0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I
M*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@
M<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M
M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY
M("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S
M<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#
M;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@
M)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-
M4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?
M(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K
M:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S
M(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I
M;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M
M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@
M)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@
M*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE
M<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;
M("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M
M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E
M871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E
M;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S
M96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I
M;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE
M("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I
M<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97([
M"G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R
M;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(
M96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER
M92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,
M;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E
M<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I
M<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE
M879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*
M<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A
M;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5
M=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!]
M.PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE
M=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@
M?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP
M('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%
M35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O
M<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)
M4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T
M;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D
M<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE
M=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT[
M"FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M
M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I
M9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]
M("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*
M)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#
M;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD
M(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY
M("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R
M96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2![
M"G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U
M9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C
M:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE
M=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI6
M15)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@
M)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G
M;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O
M<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C
M='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]
M("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X
M9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.
M5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER
M("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*
M<W5B(%]T96UP9FEL92!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@
M/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S
M<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N
M)"0B.PIO<&5N(&UY("1F:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C86XG
M="!W<FET92`D=&5M<&YA;64Z("0A(CL*8FEN;6]D92`D9F@["G!R:6YT("1F
M:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M
M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA
M;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64[
M"GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]0
M4D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*
M)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[
M4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]
M*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E
M>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%
M3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N
M86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D
M0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*
M<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG
M>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D
M14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I
M<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL
M(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O
M;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P
M<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R
M;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B
M+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I
M;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D
M("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*
M8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I
M9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]0
M4D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII
M9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*
M?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W
M*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'
M0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@
M*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G
M+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[
M)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]0
M05)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0
M?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S
M("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R
M*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?
M0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*
M?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@
M>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B([
M"GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#
M+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*
M87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*
M=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X[
M"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*
M4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@
M;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R
M(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA
M;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K
M*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`
M.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)
M5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*
M,3L*7U]%3D1?7PH`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````/__________``````````#_
M_________P`````````````````````!``````````$``````````0``````
M``#A`@````````\`````````200````````,`````````(`8````````#0``
M``````#\6P```````/7^_V\`````Z`$````````%``````````@,````````
M!@````````"H`@````````H`````````9P0````````+`````````!@`````
M````%0````````````````````,`````````"/T!```````"`````````+@%
M````````%``````````'`````````!<`````````R!(```````````!P````
M`.A:`````````P``<`````````````````<`````````<!`````````(````
M`````%@"````````"0`````````8`````````!@```````````````````#[
M__]O``````$```@`````^?__;P`````+````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'\"````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````@``````_____P`````*7P```````%5<````
M```````````````V70```````"]=````````_EX```````!,70````````9?
M``````````````````#P7@```````/5>```````````````````/7P``````
M`$=#0SH@*$%L<&EN92`V+C0N,"D@-BXT+C```"YS:'-T<G1A8@`N:6YT97)P
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;&$N9'EN`"YR96QA+G!L
M=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M90`N8W1O<G,`
M+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT
M````````````````````````````````````````````````````````````
M````````````````````````````````"P````$````"`````````,@!````
M````R`$````````>`````````````````````0```````````````````!,`
M``#V__]O`@````````#H`0```````.@!````````O``````````#````````
M``@````````````````````=````"P````(`````````J`(```````"H`@``
M`````&`)````````!`````,````(`````````!@`````````)0````,````"
M``````````@,````````"`P```````!G!````````````````````0``````
M`````````````"T````$`````@````````!P$````````'`0````````6`(`
M```````#``````````@`````````&``````````W````!````$(`````````
MR!(```````#($@```````+@%`````````P```!`````(`````````!@`````
M````00````$````&`````````(`8````````@!@````````T````````````
M````````!````````````````````$<````!````!@````````#`&```````
M`,`8````````/$,``````````````````"````````````````````!-````
M`0````8`````````_%L```````#\6P```````"P````````````````````$
M````````````````````4P````$````"`````````"A<````````*%P`````
M```;/P``````````````````"````````````````````%L````!`````@``
M``````!$FP```````$2;````````!`````````````````````0`````````
M``````````!E`````0````,`````````(/L!```````@^P```````!``````
M```````````````(````````````````````;`````$````#`````````##[
M`0``````,/L````````0````````````````````"```````````````````
M`',````!`````P````````!`^P$``````$#[````````"```````````````
M``````@```````````````````!X````!@````,`````````2/L!``````!(
M^P```````,`!````````!``````````(`````````!``````````/`````@`
M```#``````````C]`0``````"/T```````#X`0``````````````````"```
M```````(`````````($````!`````P``````````_P$```````#_````````
M>``````````````````````!````````"`````````"&`````0````,`````
M```````"``````````$``````'@````````````````````(````````````
M````````C`````@````#`````````'@``@``````>``!``````!H$```````
M````````````"````````````````````)$````!````,```````````````
M`````'@``0``````&@````````````````````$``````````0`````````!
M`````P````````````````````````"2``$``````)H`````````````````
2```!````````````````````
